Replace CONFIG_PNPACPI with CONFIG_PNP, so it loads on
ACPI-less PNPBIOS systems.

Signed-off-by: Marko Vrh <[EMAIL PROTECTED]>

----

diff -urNp linux-2.6.21/drivers/rtc/rtc-cmos.c 
linux-2.6.21.new/drivers/rtc/rtc-cmos.c
--- linux-2.6.21/drivers/rtc/rtc-cmos.c 2007-04-26 05:08:32.000000000 +0200
+++ linux-2.6.21.new/drivers/rtc/rtc-cmos.c     2007-04-26 23:58:36.000000000 
+0200
@@ -379,12 +379,12 @@ static irqreturn_t cmos_interrupt(int ir
                return IRQ_NONE;
 }

-#ifdef CONFIG_PNPACPI
-#define        is_pnpacpi()    1
+#ifdef CONFIG_PNP
+#define        is_pnp()        1
 #define        INITSECTION

 #else
-#define        is_pnpacpi()    0
+#define        is_pnp()        0
 #define        INITSECTION     __init
 #endif

@@ -427,7 +427,7 @@ cmos_do_probe(struct device *dev, struct
         * REVISIT for non-x86 systems we may need to handle io memory
         * resources: ioremap them, and request_mem_region().
         */
-       if (is_pnpacpi()) {
+       if (is_pnp()) {
                retval = request_resource(&ioport_resource, ports);
                if (retval < 0) {
                        dev_dbg(dev, "i/o registers already in use\n");
@@ -520,7 +520,7 @@ static void __exit cmos_do_remove(struct

        cmos_do_shutdown();

-       if (is_pnpacpi())
+       if (is_pnp())
                release_resource(cmos->iomem);
        rename_region(cmos->iomem, NULL);

@@ -613,7 +613,7 @@ static int cmos_resume(struct device *de
  * the device node will always be created as a PNPACPI device.
  */

-#ifdef CONFIG_PNPACPI
+#ifdef CONFIG_PNP

 #include <linux/pnp.h>

@@ -684,11 +684,11 @@ static void __exit cmos_exit(void)
 }
 module_exit(cmos_exit);

-#else  /* no PNPACPI */
+#else  /* no PNP */

 /*----------------------------------------------------------------*/

 /* Platform setup should have set up an RTC device, when PNPACPI is
  * unavailable ... this could happen even on (older) PCs.
  */

@@ -734,7 +734,7 @@ static void __exit cmos_exit(void)
 module_exit(cmos_exit);


-#endif /* !PNPACPI */
+#endif /* !PNP */

 MODULE_AUTHOR("David Brownell");
 MODULE_DESCRIPTION("Driver for PC-style 'CMOS' RTCs");
-
@@ -684,11 +684,11 @@ static void __exit cmos_exit(void)
 /*----------------------------------------------------------------*/

-/* Platform setup should have set up an RTC device, when PNPACPI is
+/* Platform setup should have set up an RTC device, when PNP is
  * unavailable ... this could happen even on (older) PCs.
  */
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to